==> haskell-gi-cairo-connector-0.1.1-277-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-KnF8kOEXzkLDwPpF0wybd
key:                  gi-cairo-connector-0.1.1-KnF8kOEXzkLDwPpF0wybd
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  4c638a6377f6ba889cb12b3ade07a1a8
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-KnF8kOEXzkLDwPpF0wybd
depends:
    base-4.17.2.1 gi-cairo-1.0.29-1aBtkjQg61h17AoKJSXGR1
    gi-cairo-render-0.1.2-BkBngUhVgdyJikxMqmXsq6
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-connector-0.1.1-300-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-Aj5QOmAaFUyGWFHmsjQiDW
key:                  gi-cairo-connector-0.1.1-Aj5QOmAaFUyGWFHmsjQiDW
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  ea6150d12fea18e66193f7807c1fc559
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-Aj5QOmAaFUyGWFHmsjQiDW
depends:
    base-4.17.2.1 gi-cairo-1.0.30-CQNrZjlYejE9Z2ZCoulzWb
    gi-cairo-render-0.1.2-AQVfMSeRqHsH5GqE3ppX29
    haskell-gi-base-0.26.9-JwtixDByddv9QLYzDFao9J mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
